function [jumptimes, systsize] = simmginfty(tmax, lambda)
% SIMMGINFTY simulate a M/G/infinity queueing system. Poisson
% arrivals of intensity lambda. Service times S: Pareto distributed  
% (can be modified).  
% 
% [jumptimes, systsize] = simmginfty(tmax, lambda)
%
% Inputs: tmax - simulation interval
%         lambda - arrival intensity 
%
% Outputs: jumptimes - times of state changes in the system
%	   systsize - number of customers in system

% Authors: R.Gaigalas, I.Kaj
% v1.2 07-Oct-02

% set default parameter values if ommited
if (nargin==0)
  tmax=1500;
  lambda=1; 
end

arrtime=-log(rand)/lambda;      % Poisson arrivals
i=1;                  
  while (min(arrtime(i,:))<=tmax)
    arrtime = [arrtime; arrtime(i, :)-log(rand)/lambda];  
    i=i+1;
  end
n=length(arrtime);              % arrival times t_1,...,t_n         

%servtime=50.*rand(n,1);        % uniform service times s_1,...,s_k

beta=0.5;                       %Pareto service times
servtime = rand^(-1/beta)-1;    %stationary renewal process
servtime = [servtime; rand(n-1,1).^(-1/(1+beta))-1];  
servtime=10.*servtime;          %arbitrary choice of mean

deptime=arrtime+servtime;     % departure times 

% Output is system size process N. 
B=[ones(n,1) arrtime ; -ones(n,1) deptime]; 
Bsort=sortrows(B,2);                 % sort jumps in order
jumps=Bsort(:,1);
jumptimes=[0;Bsort(:,2)];
systsize=[0;cumsum(jumps)];                 % M/G/$\infty$ process
  
stairs(jumptimes,systsize);
xmax=max(systsize)+5;
axis([0 tmax 0 xmax]);
grid

