function [tarr] = poissonti(tmax, lambda, ntraj)
% POISSONTI generate and plot a number of trajectories of a Poisson
%   process in a given time interval
%
% [tarr] = poissonti(tmax, lambda [, ntraj])
%
% Inputs: tmax - max time to generate the processes up to
%         lambda - arrival intensity
%         ntraj - optional, the number of trajectories to
%           generate. Default 1.
%
% Outputs: tarr - a matrix with <ntraj> columns of arrrival times of
%          the processes
%
% See also POISSONJP

% Authors: R.Gaigalas, I.Kaj
% v1.2 07-Oct-02

  % default parameter values
  if (nargin ==2)
    ntraj = 1;
  end

  % generate exponentialy distributed arrival times
  % till they cover the whole time interval
  tarr = -log(rand(1, ntraj))/lambda;  % a sample from Exp(lambda)
  i = 1;                  
  while (min(tarr(i,:))<=tmax)
    tarr = [tarr; tarr(i, :)-log(rand(1, ntraj))/lambda];  
    i = i+1;
  end

  % plot the first process 
  stairs(tarr(:, 1), 0:length(tarr)-1);  


