function [s_times, s_proc] = renewal(beta, obs_time, m_proc);
%
% [s_times, s_proc] = renewal(beta, obs_time, m_proc)
%
% Superposition of renewal processes
%
% Inputs:
%        beta - parameter of interarrival Pareto,  H=1-beta/2
%        obs_time - time variable
%        m_proc - number of processes to superpose
%
% Outputs:
%        s_times - arrival times
%        s_proc - process values
%

scale=m_proc^(1/beta);
max_time=scale*obs_time;   %time window length

  % generate arrival times: m_proc renewal processes in one vector
   a_time = rand(1, m_proc).^(-1/(1+beta))-1;
 % a_time = rand(1, m_proc).^(-1/beta)-1;
  i=1;
  while (min(a_time(i, :))<=max_time)
    a_time = [a_time; a_time(i,:)+rand(1, m_proc).^(-1/(1+beta))-1];  
    i=i+1;
  end

n_points = i; % length of the trajectories
 
  % total number of points
  v_dim = m_proc*n_points;   
  
  % merge all times to one vector
  a_time = reshape(a_time, v_dim, 1);

  % sort times to get one point process
  s_proc=sort(a_time);

  % cut off times greater than max_time and rescale 
  ex_i = find(s_proc(:, 1)>max_time);
  traj_len = ex_i(1);
  s_times = s_proc(1:traj_len, 1)./scale;

   stairs(s_times, (((1:length(s_times))-1)'./scale),'-r') ;
                              % -beta.*m_proc.*s_times), '-r');


